@@ -40,6 +40,6 @@ def test_build_parsers_missing_parent_group(tmp_path: Path):
 
         # Should raise an error when building parsers
         with pytest.raises(
-            ValueError, match=r"Parent command group 'nonexistent.parent' for command 'child' does not exist"
+            ValueError, match=r"Parent command group 'tools.nonexistent.parent' for command 'child' does not exist"
         ):
             tester.registry._build_parsers()
